@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 2.6.4.  */
+/* A Bison parser, made by GNU Bison 2.7.  */
 
 /* Bison implementation for Yacc-like parsers in C
    
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.6.4"
+#define YYBISON_VERSION "2.7"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -73,7 +73,7 @@
 #define yylloc          mkp_yylloc
 
 /* Copy the first part of user declarations.  */
-/* Line 358 of yacc.c  */
+/* Line 371 of yacc.c  */
 #line 19 "mk-parser.y"
 
 
@@ -88,7 +88,7 @@
  * maintain a separate location variable */
 #define YYLLOC_DEFAULT(Current, Rhs, N)	((Current) = YYRHSLOC(Rhs, (N) ? 1 : 0))
 
-/* Line 358 of yacc.c  */
+/* Line 371 of yacc.c  */
 #line 89 "mk-parser.y"
 
 
@@ -172,7 +172,7 @@ mkp_special_target (AnjutaToken *list)
 }
 
 
-/* Line 358 of yacc.c  */
+/* Line 371 of yacc.c  */
 #line 177 "mk-parser.c"
 
 # ifndef YY_NULL
@@ -312,7 +312,7 @@ enum { YYPUSH_MORE = 4 };
 typedef struct mkp_yypstate mkp_yypstate;
 
 #if defined __STDC__ || defined __cplusplus
-int mkp_yypush_parse (mkp_yypstate *ps, int pushed_char, YYSTYPE const *pushed_val, YYLTYPE const *pushed_loc, void* scanner);
+int mkp_yypush_parse (mkp_yypstate *ps, int pushed_char, YYSTYPE const *pushed_val, YYLTYPE *pushed_loc, void* scanner);
 #else
 int mkp_yypush_parse ();
 #endif
@@ -332,7 +332,7 @@ void mkp_yypstate_delete ();
 
 /* Copy the second part of user declarations.  */
 
-/* Line 377 of yacc.c  */
+/* Line 390 of yacc.c  */
 #line 337 "mk-parser.c"
 
 #ifdef short
@@ -968,10 +968,11 @@ do                                                              \
     }								\
 while (YYID (0))
 
-
+/* Error token number */
 #define YYTERROR	1
 #define YYERRCODE	256
 
+
 /* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
    If N is 0, then set CURRENT to the empty location which ends
    the previous symbol: RHS[0] (always defined).  */
@@ -999,17 +1000,52 @@ while (YYID (0))
 #define YYRHSLOC(Rhs, K) ((Rhs)[K])
 
 
-
 /* YY_LOCATION_PRINT -- Print the location on the stream.
    This macro was not mandated originally: define only if we know
    we won't break user code: when these are the locations we know.  */
 
 #ifndef YY_LOCATION_PRINT
 # if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
-#  define YY_LOCATION_PRINT(File, Loc)			\
-     fprintf (File, "%d.%d-%d.%d",			\
-	      (Loc).first_line, (Loc).first_column,	\
-	      (Loc).last_line,  (Loc).last_column)
+
+/* Print *YYLOCP on YYO.  Private, do not rely on its existence. */
+
+__attribute__((__unused__))
+#if (defined __STDC__ || defined __C99__FUNC__ \
+     || defined __cplusplus || defined _MSC_VER)
+static unsigned
+yy_location_print_ (FILE *yyo, YYLTYPE const * const yylocp)
+#else
+static unsigned
+yy_location_print_ (yyo, yylocp)
+    FILE *yyo;
+    YYLTYPE const * const yylocp;
+#endif
+{
+  unsigned res = 0;
+  int end_col = 0 != yylocp->last_column ? yylocp->last_column - 1 : 0;
+  if (0 <= yylocp->first_line)
+    {
+      res += fprintf (yyo, "%d", yylocp->first_line);
+      if (0 <= yylocp->first_column)
+        res += fprintf (yyo, ".%d", yylocp->first_column);
+    }
+  if (0 <= yylocp->last_line)
+    {
+      if (yylocp->first_line < yylocp->last_line)
+        {
+          res += fprintf (yyo, "-%d", yylocp->last_line);
+          if (0 <= end_col)
+            res += fprintf (yyo, ".%d", end_col);
+        }
+      else if (0 <= end_col && yylocp->first_column < end_col)
+        res += fprintf (yyo, "-%d", end_col);
+    }
+  return res;
+ }
+
+#  define YY_LOCATION_PRINT(File, Loc)          \
+  yy_location_print_ (File, &(Loc))
+
 # else
 #  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
 # endif
@@ -1017,7 +1053,6 @@ while (YYID (0))
 
 
 /* YYLEX -- calling `yylex' with the right arguments.  */
-
 #ifdef YYLEX_PARAM
 # define YYLEX yylex (&yylval, &yylloc, YYLEX_PARAM)
 #else
@@ -1084,7 +1119,7 @@ yy_symbol_value_print (yyoutput, yytype, yyvaluep, yylocationp, scanner)
   switch (yytype)
     {
       default:
-	break;
+        break;
     }
 }
 
@@ -1332,7 +1367,6 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
 {
   YYSIZE_T yysize0 = yytnamerr (YY_NULL, yytname[yytoken]);
   YYSIZE_T yysize = yysize0;
-  YYSIZE_T yysize1;
   enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
   /* Internationalized format string. */
   const char *yyformat = YY_NULL;
@@ -1395,11 +1429,13 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                     break;
                   }
                 yyarg[yycount++] = yytname[yyx];
-                yysize1 = yysize + yytnamerr (YY_NULL, yytname[yyx]);
-                if (! (yysize <= yysize1
-                       && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
-                  return 2;
-                yysize = yysize1;
+                {
+                  YYSIZE_T yysize1 = yysize + yytnamerr (YY_NULL, yytname[yyx]);
+                  if (! (yysize <= yysize1
+                         && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+                    return 2;
+                  yysize = yysize1;
+                }
               }
         }
     }
@@ -1419,10 +1455,12 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
 # undef YYCASE_
     }
 
-  yysize1 = yysize + yystrlen (yyformat);
-  if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
-    return 2;
-  yysize = yysize1;
+  {
+    YYSIZE_T yysize1 = yysize + yystrlen (yyformat);
+    if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+      return 2;
+    yysize = yysize1;
+  }
 
   if (*yymsg_alloc < yysize)
     {
@@ -1486,7 +1524,7 @@ yydestruct (yymsg, yytype, yyvaluep, yylocationp, scanner)
     {
 
       default:
-	break;
+        break;
     }
 }
 
@@ -1594,14 +1632,14 @@ yypstate_delete (yyps)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 int
-yypush_parse (yypstate *yyps, int yypushed_char, YYSTYPE const *yypushed_val, YYLTYPE const *yypushed_loc, void* scanner)
+yypush_parse (yypstate *yyps, int yypushed_char, YYSTYPE const *yypushed_val, YYLTYPE *yypushed_loc, void* scanner)
 #else
 int
 yypush_parse (yyps, yypushed_char, yypushed_val, yypushed_loc, scanner)
     yypstate *yyps;
     int yypushed_char;
     YYSTYPE const *yypushed_val;
-    YYLTYPE const *yypushed_loc;
+    YYLTYPE *yypushed_loc;
     void* scanner;
 #endif
 {
@@ -1609,10 +1647,11 @@ yypush_parse (yyps, yypushed_char, yypushed_val, yypushed_loc, scanner)
 int yychar;
 
 
-#if defined __GNUC__ && (4 < __GNUC__ + (6 <= __GNUC_MINOR__))
+#if defined __GNUC__ && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
 /* Suppress an incorrect diagnostic about yylval being uninitialized.  */
 # define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN \
     _Pragma ("GCC diagnostic push") \
+    _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")\
     _Pragma ("GCC diagnostic ignored \"-Wmaybe-uninitialized\"")
 # define YY_IGNORE_MAYBE_UNINITIALIZED_END \
     _Pragma ("GCC diagnostic pop")
@@ -1620,21 +1659,27 @@ int yychar;
 /* Default value used for initialization, for pacifying older GCCs
    or non-GCC compilers.  */
 static YYSTYPE yyval_default;
-# define YYLVAL_INITIALIZE() (yylval = yyval_default)
-#endif
-#ifndef YYLVAL_INITIALIZE
-# define YYLVAL_INITIALIZE()
+# define YY_INITIAL_VALUE(Value) = Value
 #endif
+static YYLTYPE yyloc_default
+# if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
+  = { 1, 1, 1, 1 }
+# endif
+;
 #ifndef YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
 # define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
 # define YY_IGNORE_MAYBE_UNINITIALIZED_END
 #endif
+#ifndef YY_INITIAL_VALUE
+# define YY_INITIAL_VALUE(Value) /* Nothing. */
+#endif
 
 /* The semantic value of the lookahead symbol.  */
-YYSTYPE yylval;
+YYSTYPE yylval YY_INITIAL_VALUE(yyval_default);
 
 /* Location data for the lookahead symbol.  */
-YYLTYPE yylloc;
+YYLTYPE yylloc = yyloc_default;
+
 
   int yyn;
   int yyresult;
@@ -1664,9 +1709,9 @@ YYLTYPE yylloc;
       goto yyread_pushed_token;
     }
 
-  yyss = yyssa;
-  yyvs = yyvsa;
-  yyls = yylsa;
+  yyssp = yyss = yyssa;
+  yyvsp = yyvs = yyvsa;
+  yylsp = yyls = yylsa;
   yystacksize = YYINITDEPTH;
 
   YYDPRINTF ((stderr, "Starting parse\n"));
@@ -1675,21 +1720,7 @@ YYLTYPE yylloc;
   yyerrstatus = 0;
   yynerrs = 0;
   yychar = YYEMPTY; /* Cause a token to be read.  */
-
-  /* Initialize stack pointers.
-     Waste one element of value and location stack
-     so that they stay on the same level as the state stack.
-     The wasted elements are never initialized.  */
-  yyssp = yyss;
-  yyvsp = yyvs;
-  yylsp = yyls;
-
-  YYLVAL_INITIALIZE ();
-#if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
-  /* Initialize the default location before parsing starts.  */
-  yylloc.first_line   = yylloc.last_line   = 1;
-  yylloc.first_column = yylloc.last_column = 1;
-#endif
+  yylsp[0] = *yypushed_loc;
   goto yysetstate;
 
 /*------------------------------------------------------------.
@@ -1887,7 +1918,7 @@ yyreduce:
   switch (yyn)
     {
         case 8:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 184 "mk-parser.y"
     {
         anjuta_token_merge_children ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
@@ -1896,7 +1927,7 @@ yyreduce:
     break;
 
   case 9:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 191 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_DEFINITION, NULL);
@@ -1909,7 +1940,7 @@ yyreduce:
     break;
 
   case 10:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 199 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_DEFINITION, NULL);
@@ -1921,7 +1952,7 @@ yyreduce:
     break;
 
   case 11:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 209 "mk-parser.y"
     {
         anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
@@ -1929,7 +1960,7 @@ yyreduce:
     break;
 
   case 12:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 212 "mk-parser.y"
     {
         anjuta_token_merge ((yyvsp[(1) - (4)]), (yyvsp[(2) - (4)]));
@@ -1939,7 +1970,7 @@ yyreduce:
     break;
 
   case 13:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 220 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (MK_TOKEN_RULE, NULL);
@@ -1962,7 +1993,7 @@ yyreduce:
     break;
 
   case 14:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 241 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (MK_TOKEN_COMMANDS, NULL);
@@ -1970,7 +2001,7 @@ yyreduce:
     break;
 
   case 15:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 244 "mk-parser.y"
     {
         anjuta_token_merge ((yyvsp[(1) - (4)]), (yyvsp[(2) - (4)]));
@@ -1980,7 +2011,7 @@ yyreduce:
     break;
 
   case 19:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 262 "mk-parser.y"
     {
         (yyval) = NULL;
@@ -1988,7 +2019,7 @@ yyreduce:
     break;
 
   case 20:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 265 "mk-parser.y"
     {
         (yyval) = NULL;
@@ -1996,7 +2027,7 @@ yyreduce:
     break;
 
   case 24:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 280 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (MK_TOKEN_PREREQUISITE, NULL);
@@ -2004,7 +2035,7 @@ yyreduce:
     break;
 
   case 25:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 283 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (MK_TOKEN_PREREQUISITE, NULL);
@@ -2012,7 +2043,7 @@ yyreduce:
     break;
 
   case 26:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 286 "mk-parser.y"
     {
         if ((yyvsp[(1) - (3)])) anjuta_token_set_type ((yyvsp[(1) - (3)]), ANJUTA_TOKEN_START);
@@ -2024,7 +2055,7 @@ yyreduce:
     break;
 
   case 27:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 296 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (MK_TOKEN_PREREQUISITE, NULL);
@@ -2033,7 +2064,7 @@ yyreduce:
     break;
 
   case 28:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 300 "mk-parser.y"
     {
         anjuta_token_set_type ((yyvsp[(2) - (3)]), ANJUTA_TOKEN_NEXT);
@@ -2043,7 +2074,7 @@ yyreduce:
     break;
 
   case 29:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 308 "mk-parser.y"
     {
         (yyval) = anjuta_token_merge_previous ((yyvsp[(2) - (3)]), (yyvsp[(1) - (3)]));
@@ -2052,7 +2083,7 @@ yyreduce:
     break;
 
   case 30:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 315 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_NAME, NULL);
@@ -2061,7 +2092,7 @@ yyreduce:
     break;
 
   case 31:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 319 "mk-parser.y"
     {
         anjuta_token_merge ((yyvsp[(1) - (3)]), (yyvsp[(2) - (3)]));
@@ -2070,7 +2101,7 @@ yyreduce:
     break;
 
   case 32:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 326 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (MK_TOKEN_COMMAND, NULL);
@@ -2078,7 +2109,7 @@ yyreduce:
     break;
 
   case 33:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 329 "mk-parser.y"
     {
         anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
@@ -2086,7 +2117,7 @@ yyreduce:
     break;
 
   case 34:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 338 "mk-parser.y"
     {
 		(yyval) = NULL;
@@ -2094,7 +2125,7 @@ yyreduce:
     break;
 
   case 36:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 345 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_SPACE, NULL);
@@ -2103,7 +2134,7 @@ yyreduce:
     break;
 
   case 37:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 349 "mk-parser.y"
     {
         anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
@@ -2111,7 +2142,7 @@ yyreduce:
     break;
 
   case 39:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 356 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_NAME, NULL);
@@ -2120,7 +2151,7 @@ yyreduce:
     break;
 
   case 40:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 360 "mk-parser.y"
     {
         anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
@@ -2128,7 +2159,7 @@ yyreduce:
     break;
 
   case 42:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 367 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_VALUE, NULL);
@@ -2137,7 +2168,7 @@ yyreduce:
     break;
 
   case 43:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 371 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_VALUE, NULL);
@@ -2146,7 +2177,7 @@ yyreduce:
     break;
 
   case 44:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 375 "mk-parser.y"
     {
         anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
@@ -2154,7 +2185,7 @@ yyreduce:
     break;
 
   case 45:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 378 "mk-parser.y"
     {
         anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
@@ -2162,7 +2193,7 @@ yyreduce:
     break;
 
   case 47:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 388 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (mkp_special_prerequisite ((yyvsp[(1) - (1)])), NULL);
@@ -2171,7 +2202,7 @@ yyreduce:
     break;
 
   case 48:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 392 "mk-parser.y"
     {
         anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
@@ -2179,7 +2210,7 @@ yyreduce:
     break;
 
   case 50:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 399 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (MK_TOKEN_EQUAL, NULL);
@@ -2188,7 +2219,7 @@ yyreduce:
     break;
 
   case 51:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 403 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (MK_TOKEN_IMMEDIATE_EQUAL, NULL);
@@ -2197,7 +2228,7 @@ yyreduce:
     break;
 
   case 52:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 407 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (MK_TOKEN_CONDITIONAL_EQUAL, NULL);
@@ -2206,7 +2237,7 @@ yyreduce:
     break;
 
   case 53:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 411 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (MK_TOKEN_APPEND, NULL);
@@ -2215,7 +2246,7 @@ yyreduce:
     break;
 
   case 72:
-/* Line 1813 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 455 "mk-parser.y"
     {
         mkp_scanner_parse_variable (scanner, (yyval));
@@ -2223,8 +2254,8 @@ yyreduce:
     break;
 
 
-/* Line 1813 of yacc.c  */
-#line 2228 "mk-parser.c"
+/* Line 1792 of yacc.c  */
+#line 2259 "mk-parser.c"
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2465,6 +2496,6 @@ yypushreturn:
 }
 
 
-/* Line 2076 of yacc.c  */
+/* Line 2055 of yacc.c  */
 #line 533 "mk-parser.y"
 
